# harborapi.types

`harborapi.types` defines custom types for use with `harborapi`.

::: harborapi._types
    options:
        merge_init_into_class: false
        show_if_no_docstring: true
        show_source: true
        show_bases: true
